@@ -1,23 +1,8 @@
-/***************************************************************************
- *   KSystemLog, a system log viewer tool                                  *
- *   Copyright (C) 2007 by Nicolas Ternisien                               *
- *   nicolas.ternisien@gmail.com                                           *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Nicolas Ternisien <nicolas.ternisien@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "configurationDialog.h"
 
@@ -36,7 +21,7 @@
 #include "ksystemlogConfig.h"
 
 #include "defaults.h"
-#include "logging.h"
+#include "ksystemlog_debug.h"
 
 ConfigurationDialog::ConfigurationDialog(QWidget *parent)
     : KConfigDialog(parent, i18n("Settings"), KSystemLogConfig::self())
@@ -52,7 +37,7 @@ ConfigurationDialog::~ConfigurationDialog()
 
 void ConfigurationDialog::setupLogModeConfigurations()
 {
-    logDebug() << "Setup Log Mode Configurations...";
+    qCDebug(KSYSTEMLOG) << "Setup Log Mode Configurations...";
 
     const auto logModes = Globals::instance().logModes();
     for (LogMode *logMode : logModes) {
@@ -70,7 +55,7 @@ void ConfigurationDialog::setupLogModeConfigurations()
     }
 
     for (LogModeConfigurationWidget *logModeConfigurationWidget : std::as_const(mLogModeConfigurations)) {
-        logDebug() << "Adding " << logModeConfigurationWidget->itemName() << " configuration...";
+        qCDebug(KSYSTEMLOG) << "Adding " << logModeConfigurationWidget->itemName() << " configuration...";
 
         addPage(logModeConfigurationWidget,
                 logModeConfigurationWidget->itemName(),
@@ -84,7 +69,7 @@ void ConfigurationDialog::setupLogModeConfigurations()
 
 void ConfigurationDialog::showConfiguration()
 {
-    logDebug() << "Showing Configuration dialog...";
+    qCDebug(KSYSTEMLOG) << "Showing Configuration dialog...";
 
     show();
 }
@@ -100,7 +85,7 @@ void ConfigurationDialog::setupGeneralConfiguration()
 
 void ConfigurationDialog::updateSettings()
 {
-    logDebug() << "Saving configuration...";
+    qCDebug(KSYSTEMLOG) << "Saving configuration...";
 
     mChanged = false;
 
@@ -114,18 +99,18 @@ void ConfigurationDialog::updateSettings()
 
     Q_EMIT configurationSaved();
 
-    logDebug() << "Configuration saved";
+    qCDebug(KSYSTEMLOG) << "Configuration saved";
 }
 
 bool ConfigurationDialog::hasChanged()
 {
-    logDebug() << "Current change status : " << mChanged;
+    qCDebug(KSYSTEMLOG) << "Current change status : " << mChanged;
     return mChanged;
 }
 
 void ConfigurationDialog::updateConfiguration()
 {
-    logDebug() << "Updating configuration...";
+    qCDebug(KSYSTEMLOG) << "Updating configuration...";
 
     bool valid = mGeneralConfiguration->isValid();
     if (valid) {
@@ -149,14 +134,14 @@ void ConfigurationDialog::updateConfiguration()
 
 void ConfigurationDialog::updateButtons()
 {
-    logDebug() << "Updating configuration buttons...";
+    qCDebug(KSYSTEMLOG) << "Updating configuration buttons...";
 
     mChanged = true;
 }
 
 void ConfigurationDialog::updateWidgets()
 {
-    logDebug() << "Reading configuration...";
+    qCDebug(KSYSTEMLOG) << "Reading configuration...";
 
     mGeneralConfiguration->readConfig();
     for (LogModeConfigurationWidget *logModeConfigurationWidget : std::as_const(mLogModeConfigurations)) {
@@ -168,7 +153,7 @@ void ConfigurationDialog::updateWidgets()
 
 void ConfigurationDialog::updateWidgetsDefault()
 {
-    logDebug() << "Loading default configuration...";
+    qCDebug(KSYSTEMLOG) << "Loading default configuration...";
 
     mGeneralConfiguration->defaultConfig();
     for (LogModeConfigurationWidget *logModeConfigurationWidget : std::as_const(mLogModeConfigurations)) {
