@@ -1,23 +1,8 @@
-/***************************************************************************
- *   KSystemLog, a system log viewer tool                                  *
- *   Copyright (C) 2007 by Nicolas Ternisien                               *
- *   nicolas.ternisien@gmail.com                                           *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Nicolas Ternisien <nicolas.ternisien@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "globals.h"
 
@@ -34,7 +19,7 @@
 #include "logModeConfiguration.h"
 #include "logModeConfigurationWidget.h"
 
-#include "logging.h"
+#include "ksystemlog_debug.h"
 
 Globals &Globals::instance()
 {
@@ -84,24 +69,16 @@ Globals::Globals()
 
 Globals::~Globals()
 {
-    foreach (LogModeAction *logModeAction, d->mLogModeActions) {
-        delete logModeAction;
-    }
+    qDeleteAll(d->mLogModeActions);
     d->mLogModeActions.clear();
 
-    foreach (LogMode *logMode, d->mLogModes) {
-        delete logMode;
-    }
+    qDeleteAll(d->mLogModes);
     d->mLogModes.clear();
 
-    foreach (LogLevel *logLevel, d->mLogLevels) {
-        delete logLevel;
-    }
+    qDeleteAll(d->mLogLevels);
     d->mLogLevels.clear();
 
-    foreach (LogModeFactory *factory, d->mFactories) {
-        delete factory;
-    }
+    qDeleteAll(d->mFactories);
     d->mFactories.clear();
 
     delete d;
@@ -262,13 +239,11 @@ LogMode *Globals::findLogMode(const QString &logModeName)
 void Globals::recreateLogModeActions()
 {
     // Delete existing log mode actions.
-    foreach (LogModeAction *logModeAction, d->mLogModeActions) {
-        delete logModeAction;
-    }
+    qDeleteAll(d->mLogModeActions);
     d->mLogModeActions.clear();
 
     // Create new log mode action for each log mode.
-    foreach (LogModeFactory *factory, d->mFactories) {
+    for (LogModeFactory *factory : std::as_const(d->mFactories)) {
         LogModeAction *logModeAction = factory->createLogModeAction();
         if (logModeAction) {
             d->mLogModeActions.append(logModeAction);
