@@ -1,23 +1,8 @@
-/***************************************************************************
- *   KSystemLog, a system log viewer tool                                  *
- *   Copyright (C) 2007 by Nicolas Ternisien                               *
- *   nicolas.ternisien@gmail.com                                           *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Nicolas Ternisien <nicolas.ternisien@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kioLogFileReader.h"
 
@@ -29,7 +14,7 @@
 
 #include <KDirWatch>
 
-#include "logging.h"
+#include "ksystemlog_debug.h"
 
 #define READ_SIZE 10
 
@@ -44,7 +29,7 @@ KioLogFileReader::KioLogFileReader(const LogFile &logFile)
     connect(& (fileWatch), SIGNAL(timeout()), this, SLOT(watchFile()));
     */
 
-    logDebug() << "Starting " << logFile.url().toLocalFile();
+    qCDebug(KSYSTEMLOG) << "Starting " << logFile.url().toLocalFile();
 }
 
 KioLogFileReader::~KioLogFileReader()
@@ -53,19 +38,15 @@ KioLogFileReader::~KioLogFileReader()
 
 void KioLogFileReader::open()
 {
-    logDebug() << "Opening...";
+    qCDebug(KSYSTEMLOG) << "Opening...";
     mFileJob = KIO::open(mLogFile.url(), QIODevice::ReadOnly | QIODevice::Text);
 
     connect(mFileJob, &KIO::FileJob::open, this, &KioLogFileReader::openDone);
     connect(mFileJob, SIGNAL(close(KIO::Job *)), this, SLOT(closeDone(KIO::Job *)));
 
     connect(mFileJob, &KIO::FileJob::data, this, &KioLogFileReader::dataReceived);
-#if KIO_VERSION < QT_VERSION_CHECK(5, 78, 0)
-    connect(mFileJob, &KIO::FileJob::mimetype, this, &KioLogFileReader::mimetypeReceived);
-#else
     connect(mFileJob, &KIO::FileJob::mimeTypeFound, this, &KioLogFileReader::mimetypeReceived);
-#endif
-    logDebug() << "File opened.";
+    qCDebug(KSYSTEMLOG) << "File opened.";
 }
 
 void KioLogFileReader::close()
@@ -75,20 +56,20 @@ void KioLogFileReader::close()
 
 void KioLogFileReader::openDone(KIO::Job * /*job*/)
 {
-    logDebug() << "Opening done...";
+    qCDebug(KSYSTEMLOG) << "Opening done...";
 
     mFileJob->read(READ_SIZE);
 }
 
 void KioLogFileReader::closeDone(KIO::Job * /*job*/)
 {
-    logDebug() << "Closing done...";
+    qCDebug(KSYSTEMLOG) << "Closing done...";
 }
 
 void KioLogFileReader::dataReceived(KIO::Job *job, const QByteArray &data)
 {
     if (job != mFileJob) {
-        logDebug() << "Not the good job";
+        qCDebug(KSYSTEMLOG) << "Not the good job";
         return;
     }
 
@@ -96,21 +77,21 @@ void KioLogFileReader::dataReceived(KIO::Job *job, const QByteArray &data)
         return;
     }
 
-    // logDebug() << "Receiving data... (" << totalRead << ")";
+    // qCDebug(KSYSTEMLOG) << "Receiving data... (" << totalRead << ")";
     mBuffer.append(QLatin1String(data));
     mTotalRead += data.size();
 
     emitCompleteLines();
 
-    logDebug() << "Total read : " << mTotalRead << " of " << mFileJob->size();
+    qCDebug(KSYSTEMLOG) << "Total read : " << mTotalRead << " of " << mFileJob->size();
     if (mTotalRead < mFileJob->size()) {
         mFileJob->read(READ_SIZE);
     } else {
-        logDebug() << "Entire file read, beginning file watching...";
+        qCDebug(KSYSTEMLOG) << "Entire file read, beginning file watching...";
         mFileWatch->startScan();
     }
 
-    // logDebug() << "Data received : " << buffer;
+    // qCDebug(KSYSTEMLOG) << "Data received : " << buffer;
 
     // totalRead++;
 }
@@ -118,7 +99,7 @@ void KioLogFileReader::dataReceived(KIO::Job *job, const QByteArray &data)
 void KioLogFileReader::emitCompleteLines()
 {
     int endLinePos = mBuffer.indexOf(QLatin1String("\n"));
-    forever {
+    while (true) {
         if (endLinePos == -1) {
             break;
         }
@@ -140,10 +121,10 @@ void KioLogFileReader::emitCompleteLines()
 
 void KioLogFileReader::mimetypeReceived(KIO::Job * /*job*/, const QString &type)
 {
-    logDebug() << "Mimetype received " << type;
+    qCDebug(KSYSTEMLOG) << "Mimetype received " << type;
 }
 
 void KioLogFileReader::watchFile(const QString &path)
 {
-    logDebug() << "Watch file : size : " << path;
+    qCDebug(KSYSTEMLOG) << "Watch file : size : " << path;
 }
