@@ -1,23 +1,8 @@
-/***************************************************************************
- *   KSystemLog, a system log viewer tool                                  *
- *   Copyright (C) 2007 by Nicolas Ternisien                               *
- *   nicolas.ternisien@gmail.com                                           *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Nicolas Ternisien <nicolas.ternisien@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "logManager.h"
 
@@ -25,7 +10,7 @@
 #include <KMessageBox>
 
 #include "analyzer.h"
-#include "logging.h"
+#include "ksystemlog_debug.h"
 #include "view.h"
 
 #include "logViewWidget.h"
@@ -74,11 +59,11 @@ View *LogManager::usedView() const
 void LogManager::reload()
 {
     if (!d->mLogMode) {
-        logWarning() << "Log manager is not yet initialized";
+        qCWarning(KSYSTEMLOG) << "Log manager is not yet initialized";
         return;
     }
 
-    logDebug() << "Reloading with log mode " << d->mLogMode->name() << "...";
+    qCDebug(KSYSTEMLOG) << "Reloading with log mode " << d->mLogMode->name() << "...";
 
     Q_EMIT statusBarChanged(i18n("Loading log..."));
 
@@ -86,19 +71,19 @@ void LogManager::reload()
     Q_EMIT tabTitleChanged(d->mUsedView, d->mLogMode->icon(), d->mLogMode->name());
     Q_EMIT windowTitleChanged(d->mLogMode->name());
 
-    logDebug() << "Emptying view...";
+    qCDebug(KSYSTEMLOG) << "Emptying view...";
 
     // Empty the current list, to better fill it
     d->mUsedView->logViewWidget()->model()->clear();
 
-    logDebug() << "Initializing view...";
+    qCDebug(KSYSTEMLOG) << "Initializing view...";
 
     // Init the Log View
-    logDebug() << "Initializing columns view...";
+    qCDebug(KSYSTEMLOG) << "Initializing columns view...";
 
     d->mUsedView->logViewWidget()->setColumns(d->mAnalyzer->initColumns());
 
-    logDebug() << "Reading log...";
+    qCDebug(KSYSTEMLOG) << "Reading log...";
 
     // Read the log files
     d->mAnalyzer->watchLogFiles(false);
@@ -109,7 +94,7 @@ void LogManager::reload()
     // Log List has been totally reloaded
     Q_EMIT reloaded();
 
-    logDebug() << "Log mode " << d->mLogMode->name() << " reloaded";
+    qCDebug(KSYSTEMLOG) << "Log mode " << d->mLogMode->name() << " reloaded";
 }
 
 void LogManager::stopWatching()
@@ -145,7 +130,7 @@ const QTime &LogManager::lastUpdate() const
 
 void LogManager::updateLog(int lineCount)
 {
-    logDebug() << "Updating log " << lineCount << " new lines";
+    qCDebug(KSYSTEMLOG) << "Updating log " << lineCount << " new lines";
 
     if (lineCount == 0) {
         return;
@@ -158,7 +143,7 @@ void LogManager::updateLog(int lineCount)
 
 void LogManager::cleanPreviousLogMode()
 {
-    logDebug() << "Cleaning previous LogMode...";
+    qCDebug(KSYSTEMLOG) << "Cleaning previous LogMode...";
 
     d->mLogMode = nullptr;
 
@@ -170,14 +155,17 @@ void LogManager::cleanPreviousLogMode()
 
 void LogManager::initialize(LogMode *mode, const QVariant &analyzerOptions)
 {
+    if (!mode) {
+        return;
+    }
     internalInitialize(mode, mode->createLogFiles(), analyzerOptions);
 }
 
 void LogManager::internalInitialize(LogMode *mode, const QVector<LogFile> &logFiles, const QVariant &analyzerOptions)
 {
-    logDebug() << "Initializing LogManager...";
+    qCDebug(KSYSTEMLOG) << "Initializing LogManager...";
 
-    logDebug() << "Using files" << logFiles;
+    qCDebug(KSYSTEMLOG) << "Using files" << logFiles;
 
     cleanPreviousLogMode();
 
@@ -206,7 +194,7 @@ void LogManager::internalInitialize(LogMode *mode, const QVector<LogFile> &logFi
     // Find the log files used for this kind of mode, and set them to our log manager
     d->mAnalyzer->setLogFiles(logFiles);
 
-    logDebug() << "LogManager initialized";
+    qCDebug(KSYSTEMLOG) << "LogManager initialized";
 }
 
 void LogManager::showErrorMessage(const QString &title, const QString &message)
@@ -217,7 +205,7 @@ void LogManager::showErrorMessage(const QString &title, const QString &message)
 void LogManager::setParsingPaused(bool paused)
 {
     if (!d->mLogMode) {
-        logWarning() << "Log manager is not yet initialized";
+        qCWarning(KSYSTEMLOG) << "Log manager is not yet initialized";
         return;
     }
 
@@ -233,7 +221,7 @@ void LogManager::setParsingPaused(bool paused)
 bool LogManager::isParsingPaused() const
 {
     if (!d->mLogMode) {
-        logWarning() << "Log manager is not yet initialized";
+        qCWarning(KSYSTEMLOG) << "Log manager is not yet initialized";
         return false;
     }
 
@@ -242,7 +230,7 @@ bool LogManager::isParsingPaused() const
 
 void LogManager::loadDroppedUrls(const QList<QUrl> &urls)
 {
-    logDebug() << "Drop " << urls;
+    qCDebug(KSYSTEMLOG) << "Drop " << urls;
 
     QVector<LogFile> logFiles;
     logFiles.reserve(urls.count());
