@@ -1,23 +1,8 @@
-/***************************************************************************
- *   KSystemLog, a system log viewer tool                                  *
- *   Copyright (C) 2007 by Nicolas Ternisien                               *
- *   nicolas.ternisien@gmail.com                                           *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Nicolas Ternisien <nicolas.ternisien@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "view.h"
 
@@ -30,7 +15,7 @@
 
 #include <QVBoxLayout>
 
-#include "logging.h"
+#include "ksystemlog_debug.h"
 
 #include "logViewWidget.h"
 
@@ -174,7 +159,7 @@ void View::dragEnterEvent(QDragEnterEvent *event)
 
     // If URLs have been dropped
     if (urls.isEmpty()) {
-        logWarning() << "Empty drag and drop";
+        qCWarning(KSYSTEMLOG) << "Empty drag and drop";
         return;
     }
 
@@ -184,12 +169,12 @@ void View::dragEnterEvent(QDragEnterEvent *event)
         // TODO Add a recognition of binary files (using the Url mimetype) and refuse them
 
         if (!fileInfo.isReadable()) {
-            logWarning() << "The drag and dropped file is not readable " << url.path();
+            qCWarning(KSYSTEMLOG) << "The drag and dropped file is not readable " << url.path();
             return;
         }
 
         if (fileInfo.isDir()) {
-            logWarning() << "Tried to drag and drop a directory " << url.path();
+            qCWarning(KSYSTEMLOG) << "Tried to drag and drop a directory " << url.path();
             return;
         }
     }
