@@ -1,51 +1,41 @@
-/***************************************************************************
- *   KSystemLog, a system log viewer tool                                  *
- *   Copyright (C) 2007 by Nicolas Ternisien                               *
- *   nicolas.ternisien@gmail.com                                           *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Nicolas Ternisien <nicolas.ternisien@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "logModePluginsLoader.h"
 
 #include "globals.h"
 
-#include "logging.h"
 #include "defaults.h"
+#include "ksystemlog_debug.h"
 
 // Includes existing log modes
 #include "openFactory.h"
 
 #include "systemFactory.h"
 
-#include "kernelFactory.h"
-#include "xorgFactory.h"
-#include "cronFactory.h"
-#include "daemonFactory.h"
-#include "authenticationFactory.h"
-#include "apacheFactory.h"
-#include "cupsFactory.h"
-#include "postfixFactory.h"
 #include "acpidFactory.h"
-#include "xsessionFactory.h"
+#include "apacheFactory.h"
+#include "authenticationFactory.h"
+#include "cronFactory.h"
+#include "cupsFactory.h"
+#include "daemonFactory.h"
+#include "kernelFactory.h"
+#include "postfixFactory.h"
 #include "sambaFactory.h"
+#include "xorgFactory.h"
+#include "xsessionFactory.h"
+#ifdef HAVE_JOURNALD
 #include "journaldFactory.h"
+#endif
+#ifdef HAVE_AUDIT
+#include "auditFactory.h"
+#endif
 
 LogModePluginsLoader::LogModePluginsLoader(QWidget *parent)
-    : parent(parent)
+    : mParent(parent)
 {
 }
 
@@ -56,7 +46,7 @@ LogModePluginsLoader::~LogModePluginsLoader()
 void LogModePluginsLoader::loadPlugins()
 {
     // Open Log mode needs the current window to display error messages and open dialogs
-    Globals::instance().registerLogModeFactory(new OpenLogModeFactory(parent));
+    Globals::instance().registerLogModeFactory(new OpenLogModeFactory(mParent));
 
     // System
     Globals::instance().registerLogModeFactory(new SystemLogModeFactory());
@@ -94,6 +84,11 @@ void LogModePluginsLoader::loadPlugins()
     // XSession
     Globals::instance().registerLogModeFactory(new XSessionLogModeFactory());
 
+    // Audit
+#ifdef HAVE_AUDIT
+    Globals::instance().registerLogModeFactory(new AuditLogModeFactory());
+#endif
+
     // Journald
 #ifdef HAVE_JOURNALD
     Globals::instance().registerLogModeFactory(new JournaldModeFactory());
