@@ -1,23 +1,8 @@
-/***************************************************************************
- *   KSystemLog, a system log viewer tool                                  *
- *   Copyright (C) 2007 by Nicolas Ternisien                               *
- *   nicolas.ternisien@gmail.com                                           *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Nicolas Ternisien <nicolas.ternisien@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include <QApplication>
 #include <QCommandLineParser>
@@ -25,8 +10,8 @@
 #include <KAboutData>
 #include <KLocalizedString>
 
+#include "ksystemlog_debug.h"
 #include "ksystemlog_version.h"
-#include "logging.h"
 #include "mainWindow.h"
 
 int main(int argc, char **argv)
@@ -93,7 +78,7 @@ int main(int argc, char **argv)
             // KSystemLog::MainWindow* mainWindow;
             new KSystemLog::MainWindow();
             for (int i = 0, total = args.count(); i < total; ++i) {
-                logDebug() << "Loading file " << args.at(i);
+                qCDebug(KSYSTEMLOG) << "Loading file " << args.at(i);
 
                 // TODO Implement this kind of loading
                 // LogManager* firstLogManager = d->tabs->createTab();
