@@ -1,23 +1,8 @@
-/***************************************************************************
- *   KSystemLog, a system log viewer tool                                  *
- *   Copyright (C) 2007 by Nicolas Ternisien                               *
- *   nicolas.ternisien@gmail.com                                           *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Nicolas Ternisien <nicolas.ternisien@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "mainWindow.h"
 
@@ -55,7 +40,7 @@
 #include "logLevel.h"
 #include "logMode.h"
 
-#include "logging.h"
+#include "ksystemlog_debug.h"
 
 #include "logModePluginsLoader.h"
 #include "logViewSearchWidget.h"
@@ -68,13 +53,13 @@ namespace KSystemLog
 MainWindow::MainWindow()
     : KXmlGuiWindow(nullptr)
 {
-    logDebug() << "Starting KSystemLog...";
+    qCDebug(KSYSTEMLOG) << "Starting KSystemLog...";
 
     // Load log modes plugins
     loadLogModePlugins();
 
     // Create the GUI from XML configuration
-    logDebug() << "Creating Gui...";
+    qCDebug(KSYSTEMLOG) << "Creating Gui...";
     createGUI();
 
     // TODO Improve the status bar to add a custom widget which shows an history of latest message, and add a
@@ -95,7 +80,7 @@ MainWindow::MainWindow()
     // automatically save settings if changed: window size, toolbar
     // position, icon size, etc.  Also to add actions for the statusbar
     // toolbar, and keybindings if necessary.
-    logDebug() << "Setup Gui...";
+    qCDebug(KSYSTEMLOG) << "Setup Gui...";
     setupGUI();
 
     // Setup Logs menu, needs to be called after setupGUI()
@@ -122,7 +107,7 @@ MainWindow::MainWindow()
             if (mode->filesExist()) {
                 mTabs->load(mode, firstLogManager);
             } else {
-                logWarning() << mode->name() << "is selected by default, but log files do not exist.";
+                qCWarning(KSYSTEMLOG) << mode->name() << "is selected by default, but log files do not exist.";
             }
         }
     }
@@ -144,7 +129,7 @@ void MainWindow::loadLogModePlugins()
 
 void MainWindow::setupTabLogViews()
 {
-    logDebug() << "Creating tab widget...";
+    qCDebug(KSYSTEMLOG) << "Creating tab widget...";
 
     mTabs = new TabLogViewsWidget(this);
 
@@ -173,7 +158,7 @@ void MainWindow::setupStatusBar()
 
 void MainWindow::prepareCreatedLogManager(LogManager *manager)
 {
-    logDebug() << "Connecting to actions the new log manager and view...";
+    qCDebug(KSYSTEMLOG) << "Connecting to actions the new log manager and view...";
 
     // Contextual menu Log Manager signals
 
@@ -226,7 +211,7 @@ void MainWindow::updateDetailDialog()
 
 void MainWindow::updateSelection()
 {
-    // logDebug() << "Updating selection...";
+    // qCDebug(KSYSTEMLOG) << "Updating selection...";
 
     LogManager *currentLogManager = mTabs->activeLogManager();
 
@@ -260,7 +245,8 @@ void MainWindow::updateReloading()
     mTabs->changeReloadingTab(currentView, !enabled);
 
     // Enables/Disables all Log Mode menus (useful for multiple actions menus)
-    foreach (LogModeAction *logModeAction, Globals::instance().logModeActions()) {
+    const auto logModeActions{Globals::instance().logModeActions()};
+    for (LogModeAction *logModeAction : logModeActions) {
         logModeAction->actionMenu()->setEnabled(enabled);
     }
 }
@@ -273,7 +259,7 @@ void MainWindow::closeEvent(QCloseEvent *event)
     if (currentLogManager) {
         currentLogManager->stopWatching();
     }
-    logDebug() << "Saving configuration before exit...";
+    qCDebug(KSYSTEMLOG) << "Saving configuration before exit...";
     qCDebug(KSYSTEMLOG) << "Saving configuration before exit...";
     // Write the config to the file
     KSystemLogConfig::self()->save();
@@ -300,7 +286,8 @@ void MainWindow::toggleItemTooltip(bool enabled)
 {
     KSystemLogConfig::setTooltipEnabled(enabled);
 
-    foreach (LogManager *manager, mTabs->logManagers()) {
+    const auto logManagers{mTabs->logManagers()};
+    for (LogManager *manager : logManagers) {
         manager->usedView()->logViewWidget()->toggleToolTip(enabled);
     }
 }
@@ -312,7 +299,7 @@ void MainWindow::toggleNewLinesDisplaying(bool displayed)
 
 void MainWindow::updateStatusBar()
 {
-    logDebug() << "Updating status bar...";
+    qCDebug(KSYSTEMLOG) << "Updating status bar...";
 
     LogManager *currentManager = mTabs->activeLogManager();
 
@@ -331,14 +318,14 @@ void MainWindow::updateStatusBar()
 
 void MainWindow::toggleResumePauseParsing(bool paused)
 {
-    logDebug() << "Pausing parsing : " << paused;
+    qCDebug(KSYSTEMLOG) << "Pausing parsing : " << paused;
 
     LogManager *currentLogManager = mTabs->activeLogManager();
     if (currentLogManager) {
         currentLogManager->setParsingPaused(paused);
     }
 
-    logDebug() << "Parsing paused : " << paused;
+    qCDebug(KSYSTEMLOG) << "Parsing paused : " << paused;
 }
 
 void MainWindow::changeResumePauseAction(bool paused)
@@ -364,7 +351,8 @@ void MainWindow::changeResumePauseAction(bool paused)
     }
 
     // Be sure that the button will always have a good size
-    foreach (QWidget *widget, mResumePauseAction->associatedWidgets()) {
+    const auto associatedWidgets{mResumePauseAction->associatedWidgets()};
+    for (QWidget *widget : associatedWidgets) {
         if (widget->sizeHint().width() > widget->size().width()) {
             widget->setMinimumSize(widget->sizeHint());
         }
@@ -379,13 +367,13 @@ void MainWindow::fileOpen()
 
 void MainWindow::showConfigurationDialog()
 {
-    logDebug() << "Showing configuration dialog...";
+    qCDebug(KSYSTEMLOG) << "Showing configuration dialog...";
     mConfigurationDialog->showConfiguration();
 }
 
 void MainWindow::showLogMessageDialog()
 {
-    logDebug() << "Launching the Send message dialog box...";
+    qCDebug(KSYSTEMLOG) << "Launching the Send message dialog box...";
 
     if (!mLoggedDialog) {
         mLoggedDialog = new LoggerDialog(this);
@@ -408,7 +396,7 @@ void MainWindow::changeWindowTitle(const QString &text)
 
 void MainWindow::changeCurrentTab()
 {
-    logDebug() << "Tab has changed";
+    qCDebug(KSYSTEMLOG) << "Tab has changed";
 
     LogManager *currentManager = mTabs->activeLogManager();
 
@@ -455,7 +443,7 @@ void MainWindow::changeCurrentTab()
     // Updating Detail dialog
     updateDetailDialog();
 
-    logDebug() << "Tab changing done";
+    qCDebug(KSYSTEMLOG) << "Tab changing done";
 }
 
 /**
@@ -467,7 +455,7 @@ void MainWindow::changeCurrentTab()
  */
 void MainWindow::saveProperties(KConfigGroup & /*configuration*/)
 {
-    logDebug() << "Saving properties...";
+    qCDebug(KSYSTEMLOG) << "Saving properties...";
 }
 
 /**
@@ -480,14 +468,15 @@ void MainWindow::saveProperties(KConfigGroup & /*configuration*/)
  */
 void MainWindow::readProperties(const KConfigGroup & /*configuration*/)
 {
-    logDebug() << "Reading properties...";
+    qCDebug(KSYSTEMLOG) << "Reading properties...";
 }
 
 void MainWindow::toggleFilterBar()
 {
-    logDebug() << "Toggling filter bar..." << mFilterBarAction->isChecked();
+    qCDebug(KSYSTEMLOG) << "Toggling filter bar..." << mFilterBarAction->isChecked();
 
-    foreach (LogManager *manager, mTabs->logManagers()) {
+    const auto logManagers{mTabs->logManagers()};
+    for (LogManager *manager : logManagers) {
         manager->usedView()->toggleLogViewFilter(mFilterBarAction->isChecked());
     }
 
@@ -508,7 +497,7 @@ void MainWindow::findPrevious()
 
 void MainWindow::showSearchBar()
 {
-    logDebug() << "Showing search bar...";
+    qCDebug(KSYSTEMLOG) << "Showing search bar...";
 
     LogManager *activeLogManager = mTabs->activeLogManager();
 
@@ -525,7 +514,7 @@ void MainWindow::showSearchBar()
 
 void MainWindow::setupActions()
 {
-    logDebug() << "Creating actions...";
+    qCDebug(KSYSTEMLOG) << "Creating actions...";
 
     QAction *fileOpenAction = actionCollection()->addAction(KStandardAction::Open, this, SLOT(fileOpen()));
     fileOpenAction->setToolTip(i18n("Open a file in KSystemLog"));
@@ -724,10 +713,11 @@ void MainWindow::selectLogModeAction(bool)
     ActionData actionData = action->data().value<ActionData>();
     QString selectedModeId = actionData.id;
 
-    logDebug() << "Selected action" << selectedModeId;
+    qCDebug(KSYSTEMLOG) << "Selected action" << selectedModeId;
 
     LogMode *currentMode = nullptr;
-    foreach (LogMode *logMode, Globals::instance().logModes()) {
+    const auto logModes{Globals::instance().logModes()};
+    for (LogMode *logMode : logModes) {
         if (logMode->id() == selectedModeId) {
             currentMode = logMode;
             break;
@@ -735,11 +725,11 @@ void MainWindow::selectLogModeAction(bool)
     }
 
     if (!currentMode) {
-        logCritical() << "The selected mode does not exist";
+        qCCritical(KSYSTEMLOG) << "The selected mode does not exist";
         return;
     }
 
-    logDebug() << "Selecting " << currentMode->name() << " (" << currentMode->id() << ")";
+    qCDebug(KSYSTEMLOG) << "Selecting " << currentMode->name() << " (" << currentMode->id() << ")";
 
     mTabs->load(currentMode, mTabs->activeLogManager(), actionData.analyzerOptions);
 }
@@ -763,7 +753,8 @@ void MainWindow::setupLogModeMenu()
     auto servicesAction = new KActionMenu(QIcon::fromTheme(QStringLiteral("preferences-system-session-services")), i18n("Services"), this);
     auto othersAction = new KActionMenu(QIcon::fromTheme(QStringLiteral("preferences-other")), i18n("Others"), this);
 
-    foreach (LogModeAction *logModeAction, Globals::instance().logModeActions()) {
+    const auto logModeActions{Globals::instance().logModeActions()};
+    for (LogModeAction *logModeAction : logModeActions) {
         if (logModeAction->category() == LogModeAction::RootCategory) {
             menuLogModeActions.append(logModeAction->actionMenu());
         } else if (logModeAction->category() == LogModeAction::ServicesCategory) {
@@ -791,11 +782,13 @@ void MainWindow::setupLogModeMenu()
 void MainWindow::setupLogActions()
 {
     // Sets up log mode actions.
-    foreach (LogModeAction *logModeAction, Globals::instance().logModeActions()) {
-        foreach (QAction *action, logModeAction->innerActions()) {
+    const auto logModeActions{Globals::instance().logModeActions()};
+    for (LogModeAction *logModeAction : logModeActions) {
+        const auto innerActions{logModeAction->innerActions()};
+        for (QAction *action : innerActions) {
             ActionData actionData = action->data().value<ActionData>();
             if (actionData.addToActionCollection) {
-                logDebug() << "Adding action" << actionData.id;
+                qCDebug(KSYSTEMLOG) << "Adding action" << actionData.id;
                 action = actionCollection()->addAction(actionData.id, action);
             }
             connect(action, &QAction::triggered, this, &MainWindow::selectLogModeAction);
