@@ -1,23 +1,8 @@
-/***************************************************************************
- *   KSystemLog, a system log viewer tool                                  *
- *   Copyright (C) 2007 by Nicolas Ternisien                               *
- *   nicolas.ternisien@gmail.com                                           *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Nicolas Ternisien <nicolas.ternisien@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "fileListHelper.h"
 
@@ -31,7 +16,7 @@
 
 #include "defaults.h"
 
-#include "logging.h"
+#include "ksystemlog_debug.h"
 
 FileListHelper::FileListHelper(QWidget *p)
     : mParent(p)
@@ -87,7 +72,7 @@ QStringList FileListHelper::findPaths(const QList<QUrl> &urls)
             // If this Url uses a joker (i.e. : "/var/log/apache2/*")
             if (url.fileName().contains(QLatin1Char('*'))) {
                 const QStringList foundPaths = expandJoker(url);
-                logDebug() << "Found paths of " << url.path() << ":" << foundPaths;
+                qCDebug(KSYSTEMLOG) << "Found paths of " << url.path() << ":" << foundPaths;
                 for (const QString &foundPath : foundPaths) {
                     paths.append(foundPath);
                 }
@@ -153,7 +138,7 @@ QStringList FileListHelper::expandJoker(const QUrl &url)
 {
     const QFileInfo info(url.toLocalFile());
 
-    logDebug() << "Dir " << info.dir().path();
+    qCDebug(KSYSTEMLOG) << "Dir " << info.dir().path();
     const QString filename = info.fileName();
 
     if (filename.isEmpty()) {
