@@ -1,30 +1,15 @@
-/***************************************************************************
- *   KSystemLog, a system log viewer tool                                  *
- *   Copyright (C) 2007 by Nicolas Ternisien                               *
- *   nicolas.ternisien@gmail.com                                           *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Nicolas Ternisien <nicolas.ternisien@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "genericConfiguration.h"
 
 #include <KLocalizedString>
 
 #include "defaults.h"
-#include "logging.h"
+#include "ksystemlog_debug.h"
 
 #include "globals.h"
 
@@ -33,7 +18,7 @@ GenericLogModeConfiguration::GenericLogModeConfiguration(const QString &configur
                                                          const QStringList &defaultLogFilesPaths,
                                                          const QList<int> &defaultLogFilesLevels)
 {
-    logDebug() << "Using Configuration Group : " << configurationGroup;
+    qCDebug(KSYSTEMLOG) << "Using Configuration Group : " << configurationGroup;
     mConfiguration->setCurrentGroup(configurationGroup);
 
     mConfiguration->addItemStringList(QStringLiteral("LogFilesPaths"), mLogFilesPaths, defaultLogFilesPaths, QStringLiteral("LogFilesPaths"));
@@ -70,7 +55,7 @@ QVector<LogFile> GenericLogModeConfiguration::findGenericLogFiles() const
     QVector<LogFile> logFiles;
 
     if (mLogFilesPaths.size() != mLogFilesLevels.size()) {
-        logDebug() << i18n("The two arrays size are different, skipping the reading of log files.");
+        qCDebug(KSYSTEMLOG) << i18n("The two arrays size are different, skipping the reading of log files.");
         return logFiles;
     }
 
@@ -87,7 +72,7 @@ QVector<LogFile> GenericLogModeConfiguration::findGenericLogFiles() const
 
         const QUrl url = QUrl::fromLocalFile(stringValue);
         if (!url.isValid()) {
-            logWarning() << i18n("URL '%1' is not valid, skipping this URL.", url.path());
+            qCWarning(KSYSTEMLOG) << i18n("URL '%1' is not valid, skipping this URL.", url.path());
             continue;
         }
 
