@@ -1,23 +1,9 @@
-/***************************************************************************
- *   KApacheLog, a apache log viewer tool                                  *
- *   Copyright (C) 2007 by Nicolas Ternisien                               *
- *   nicolas.ternisien@gmail.com                                           *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    KApacheLog, a apache log viewer tool
+    SPDX-FileCopyrightText: 2007 Nicolas Ternisien <nicolas.ternisien@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "cupsConfigurationWidget.h"
 
@@ -42,7 +28,7 @@ CupsConfigurationWidget::CupsConfigurationWidget()
 
 void CupsConfigurationWidget::saveConfig()
 {
-    logDebug() << "Saving config from Cups Options...";
+    qCDebug(KSYSTEMLOG) << "Saving config from Cups Options...";
 
     auto *cupsConfiguration = Globals::instance().findLogMode(QStringLiteral(CUPS_LOG_MODE_ID))->logModeConfiguration<CupsConfiguration *>();
     cupsConfiguration->setCupsPaths(mCupsFileList->paths(mCupsPathsId));
@@ -72,10 +58,10 @@ void CupsConfigurationWidget::readConfig()
 bool CupsConfigurationWidget::isValid() const
 {
     if (mCupsFileList->isOneOfCategoryEmpty()) {
-        logDebug() << "Cups configuration not valid";
+        qCDebug(KSYSTEMLOG) << "Cups configuration not valid";
         return false;
     }
 
-    logDebug() << "Cups configuration valid";
+    qCDebug(KSYSTEMLOG) << "Cups configuration valid";
     return true;
 }
